Thread (3 messages) flat view 3 messages, 2 authors, 17h ago
HOTtoday

[PATCH] e1000e: rename init/exit module functions to avoid confusion with e1000

From: Filip Balluch <hidden>
Date: 2026-09-15 12:26:51
Also in: intel-wired-lan, lkml
Subsystem: intel ethernet drivers, networking drivers, the rest · Maintainers: Tony Nguyen, Przemek Kitszel, Andrew Lunn, "David S. Miller", Eric Dumazet, Jakub Kicinski, Paolo Abeni, Linus Torvalds

The e1000e driver uses e1000_init_module and e1000_exit_module as its
module init/exit function names, which are identical to those used by the
older e1000 driver. Rename them to e1000e_init_module and
e1000e_exit_module to clearly distinguish e1000e from the legacy e1000
driver.

Signed-off-by: Filip Balluch <redacted>
---
 drivers/net/ethernet/intel/e1000e/netdev.c | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)
diff --git a/drivers/net/ethernet/intel/e1000e/netdev.c b/drivers/net/ethernet/intel/e1000e/netdev.c
index 844f31ab37ad..2a4cf75bce34 100644
--- a/drivers/net/ethernet/intel/e1000e/netdev.c
+++ b/drivers/net/ethernet/intel/e1000e/netdev.c
@@ -8203,31 +8203,31 @@ static struct pci_driver e1000_driver = {
 };
 
 /**
  * e1000_init_module - Driver Registration Routine
  *
  * e1000_init_module is the first routine called when the driver is
  * loaded. All it does is register with the PCI subsystem.
  **/
-static int __init e1000_init_module(void)
+static int __init e1000e_init_module(void)
 {
 	pr_info("Intel(R) PRO/1000 Network Driver\n");
 	pr_info("Copyright(c) 1999 - 2015 Intel Corporation.\n");
 
 	return pci_register_driver(&e1000_driver);
 }
-module_init(e1000_init_module);
+module_init(e1000e_init_module);
 
 /**
  * e1000_exit_module - Driver Exit Cleanup Routine
  *
  * e1000_exit_module is called just before the driver is removed
  * from memory.
  **/
-static void __exit e1000_exit_module(void)
+static void __exit e1000e_exit_module(void)
 {
 	pci_unregister_driver(&e1000_driver);
 }
-module_exit(e1000_exit_module);
+module_exit(e1000e_exit_module);
 
 MODULE_DESCRIPTION("Intel(R) PRO/1000 Network Driver");
 MODULE_LICENSE("GPL v2");
@@ -8203,31 +8203,31 @@ static struct pci_driver e1000_driver = {
 
 /**
- * e1000_init_module - Driver Registration Routine
+ * e1000e_init_module - Driver Registration Routine
  *
@@ -8203,31 +8203,31 @@ static struct pci_driver e1000_driver = {
  *
- * e1000_init_module is the first routine called when the driver is
+ * e1000e_init_module is the first routine called when the driver is
  * loaded. All it does is register with the PCI subsystem.
  **/
@@ -8203,31 +8203,31 @@ static struct pci_driver e1000_driver = {
 
 /**
- * e1000_exit_module - Driver Exit Cleanup Routine
+ * e1000e_exit_module - Driver Exit Cleanup Routine
  *
@@ -8203,31 +8203,31 @@ static struct pci_driver e1000_driver = {
  *
- * e1000_exit_module is called just before the driver is removed
+ * e1000e_exit_module is called just before the driver is removed
  * from memory.
  **/
-- 
2.55.0
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help